@@ -41,7 +41,7 @@ if (is.numeric(x) & is.null(ty)) {
   ty <- c(1:length(y))
 }
 
-possible.distances <- c("euclidean", "manhattan", "minkowski", "infnorm", "ccor", "sts", "dtw", "lb.keogh", "edr", "erp", "lcss", "fourier", "tquest", "dissim", "acf", "pacf", "ar.lpc.ceps", "ar.mah", "ar.mah.statistic", "ar.mah.pvalue", "ar.pic", "cdm", "cid", "cor", "cort", "wav", "int.per", "per", "mindist.sax", "ncd", "pred", "spec.glk", "spec.isd", "spec.llr", "pdc", "frechet")
+possible.distances <- c("euclidean", "manhattan", "minkowski", "infnorm", "ccor", "sts", "dtw", "lb.keogh", "edr", "erp", "lcss", "fourier", "tquest", "dissim", "acf", "pacf", "ar.lpc.ceps", "ar.mah", "ar.mah.statistic", "ar.mah.pvalue", "ar.pic", "cdm", "cid", "cor", "cort", "wav", "int.per", "per", "mindist.sax", "ncd", "pred", "spec.glk", "spec.isd", "spec.llr", "pdc", "frechet", "tam")
 
 distance <- match.arg(distance, possible.distances)
 
@@ -82,7 +82,8 @@ d<-switch(distance,
        "spec.isd" = SpecISDDistance(x, y, ...),
        "spec.llr" = SpecLLRDistance(x, y, ...),
        "pdc" = PDCDistance(x, y, ...),
-       "frechet" = FrechetDistance(x, y, tx, ty)
+       "frechet" = FrechetDistance(x, y, tx, ty),
+       "tam" = TAMDistance(x, y)
        )
   
 return(d)
